SystemRng

Struct SystemRng 

pub struct SystemRng;
๐Ÿ”ฌThis is a nightly-only experimental API. (random #130703)
The system random number generator.

This asks the system for random data suitable for cryptographic purposes such as key generation. If security is a concern, consult the platform documentation below for the specific guarantees your target provides.

The high quality of randomness provided by this source means it can be quite slow on some targets. If you need a large quantity of random numbers and security is not a concern, consider using an alternative random number generator (potentially seeded from this one).

If you need to fill a buffer with random bytes, use SystemRng.fill_bytes(&mut buf).

Underlying sources

PlatformSource
Linuxgetrandom or /dev/urandom after polling /dev/random
WindowsProcessPrng
AppleCCRandomGenerateBytes
DragonFlyarc4random_buf
ESP-IDFesp_fill_random
FreeBSDarc4random_buf
Fuchsiacprng_draw
Haikuarc4random_buf
Illumosarc4random_buf
NetBSDarc4random_buf
OpenBSDarc4random_buf
Solarisarc4random_buf
Vitaarc4random_buf
Hermitread_entropy
Horizon, Cygwingetrandom
AIX, Hurd, L4Re, QNX/dev/urandom
Redox/scheme/rand
RTEMSarc4random_buf
SGXrdrand
SOLIDSOLID_RNG_SampleRandomBytes
TEEOSTEE_GenerateRandom
UEFIEFI_RNG_PROTOCOL
VxWorksrandABytes after waiting for randSecure to become ready
WASIp1random_get
WASIp2get-random-bytes
WASIp3get-random-bytes
ZKVMsys_rand

Note that the sources used might change over time.

Consult the documentation for the underlying operations on your supported targets to determine whether they provide any particular desired properties, such as support for reseeding on VM fork operations.